@@ -225,10 +225,14 @@ MainWindow::MainWindow(QWidget *parent)
         }
     }
     drawLevel();
-    /*this->addAction(ui->actionUp);
+    this->addAction(ui->actionUp);
     this->addAction(ui->actionDown);
     this->addAction(ui->actionLeft);
-    this->addAction(ui->actionRigth);*/
+    this->addAction(ui->actionRigth);
+    this->addAction(ui->actionUp_2);
+    this->addAction(ui->actionDown_2);
+    this->addAction(ui->actionLeft_2);
+    this->addAction(ui->actionRigth_2);
 }
 
 MainWindow::~MainWindow()
@@ -1016,3 +1020,23 @@ void MainWindow::on_actionRigth_triggered()
 {
     on_btnRigth_pressed();
 }
+
+void MainWindow::on_actionUp_2_triggered()
+{
+     on_btnUp_pressed();
+}
+
+void MainWindow::on_actionDown_2_triggered()
+{
+     on_btnDown_pressed();
+}
+
+void MainWindow::on_actionLeft_2_triggered()
+{
+  on_btnLeft_pressed();
+}
+
+void MainWindow::on_actionRigth_2_triggered()
+{
+   on_btnRigth_pressed();
+}
