@@ -47,6 +47,14 @@ private slots:
 
     void on_actionRigth_triggered();
 
+    void on_actionUp_2_triggered();
+
+    void on_actionDown_2_triggered();
+
+    void on_actionLeft_2_triggered();
+
+    void on_actionRigth_2_triggered();
+
 private:
     Ui::MainWindow *ui;
 
